﻿using BlazorApp.Models;
using BlazorApp.Pages;
using BlazorApp.Services;
using Blazorise;
using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components;
using Microsoft.Extensions.Localization;
using Microsoft.JSInterop;
using System.Collections.ObjectModel;
using System.Collections.Specialized;

namespace BlazorApp.Components
{
    public partial class InventoryComponent
    {
        [Inject]
        public IDataService DataService { get; set; }



        private int totalItem;

        public Item CurrentDragItem { get; set; }

        public int CurrentDragItemIndex { get; set; }

        [CascadingParameter]
        public InventoryComponent Parent { get; set; }

        private bool choiceSort = false;
        public List<Item> RecipeItems { get; set; }
        [Parameter]
        public List<Item> Items { get; set; } = new List<Item>();
        public ObservableCollection<InventoryAction> Actions { get; set; }

        [Inject]
        internal IJSRuntime JavaScriptRuntime { get; set; }

        public InventoryComponent()
        {
            Actions = new ObservableCollection<InventoryAction>();
            Actions.CollectionChanged += OnActionsCollectionChanged;
            this.RecipeItems = new List<Item> { null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null };
        }

        private async Task OnReadData(DataGridReadDataEventArgs<Item> e)
        {
            if (e.CancellationToken.IsCancellationRequested)
            {
                return;
            }

            if (!e.CancellationToken.IsCancellationRequested)
            {
                Items = await DataService.List(e.Page, e.PageSize);
                totalItem = await DataService.Count();
            }
        }
        private void OnActionsCollectionChanged(object? sender, NotifyCollectionChangedEventArgs e)
        {
            JavaScriptRuntime.InvokeVoidAsync("Crafting.AddActions", e.NewItems);
        }

        protected override async Task OnAfterRenderAsync(bool firstRender)
        {
            base.OnAfterRenderAsync(firstRender);

            if (!firstRender)
            {
                return;
            }


            StateHasChanged();
        }

        private void SortByame()
        {
            if (choiceSort)
            {
                Items.Sort((x, y) => x.Id.CompareTo(y.Id));
                choiceSort = !choiceSort;
                Actions.Add(new InventoryAction { Action = "Sort by Id" });
            }
            else
            {
                Items.Sort((x, y) => x.Name.CompareTo(y.Name));
                choiceSort = !choiceSort;
                Actions.Add(new InventoryAction { Action = "Sort by Name" });
            }
        }

    }
}
