﻿using BlazorApp.Models;
using BlazorApp.Pages;
using Blazorise;
using Microsoft.AspNetCore.Components;

namespace BlazorApp.Components
{
    public partial class InventoryItem
    {
        [Parameter]
        public int Index { get; set; }

        [Parameter]
        public Item Item { get; set; }





        [Parameter]
        public bool NoDrop { get; set; }

        [CascadingParameter]
        public InventoryComponent Parent { get; set; }

        internal void OnDragEnter()
        {
            if (NoDrop)
            {
                return;
            }

            Parent.Actions.Add(new InventoryAction { Action = "Drag Enter", Item = this.Item, Index = this.Index });
        }

        internal void OnDragLeave()
        {
            if (NoDrop)
            {
                return;
            }

            Parent.Actions.Add(new InventoryAction { Action = "Drag Leave", Item = this.Item, Index = this.Index });
        }

        internal void OnDrop()
        {
            
            if (NoDrop == true || Parent.CurrentDragItem == null)
            {
                return;
            }
            if(this.Item == null)
            {
                this.Item = ItemFactory.Create(Parent.CurrentDragItem);
            }
            else if(this.Item.Id == Parent.CurrentDragItem.Id){
                if(this.Item.StackSize > this.Item.Num){
                    ItemFactory.Add1(this.Item, this.Item);
                }
                
            }


            Parent.Actions.Add(new InventoryAction { Action = "Drop", Item = this.Item, Index = this.Index });

        }

        private void OnDragStart()
        {
            
            Parent.CurrentDragItem = this.Item;
            Parent.CurrentDragItemIndex = this.Index;

            Parent.Actions.Add(new InventoryAction { Action = "Drag Start", Item = this.Item, Index = this.Index });
        }

        private void OnDragEnd()
        {
            if (Parent.Actions.Last().Action == "Drag Leave")
            {
                this.Item = null;
            }
            Parent.Actions.Add(new InventoryAction { Action = "Delete", Item = this.Item, Index = this.Index });
        }
    }
}
